import { Close, Hamburger } from 'icon-ng'
import { action, observable, useStrict } from 'mobx'

import React from 'react'
import { observer } from 'mobx-react'

useStrict(true)

let _state = observable({
  isClosed: []
})

let _size = 5
while (_size--) {
  _state.isClosed.push(true)
}

const Sidenav = {
  toggleButtonState: action((id) => {
    _state.isClosed[id] = !_state.isClosed[id]
  }),
  Button: observer(
    ({ buttonSize = 30, buttonPositionClass, menuPositionClass = 'left', iconOpen = <Hamburger size={buttonSize} />, iconClose = <Close size={buttonSize} />, id = 0, children }) => {
      let icon = _state.isClosed[id] ? iconOpen : iconClose

      let buttonClass = 'icon'
      buttonClass += buttonPositionClass ? ` ${buttonPositionClass}` : ``
      buttonClass += !_state.isClosed[id] ? ` inline` : ``

      let menuClass = _state.isClosed[id] ? 'closed' : 'open'
      menuClass += menuPositionClass ? ` ${menuPositionClass}` : ``

      return (
        <div>
          <div className={buttonClass} onClick={() => Sidenav.toggleButtonState(id)}>{icon}</div>
          <div className={menuClass}>{children}</div>
          <style jsx>{`
            user-select: none; 
            display: inline;
            .closed {    
              display: none;} 
            .open {
              position: fixed;    
              z-index: 9998;            
              background-color: seashell;
              padding-left: 10px;
              height: 100%;                      
              min-width: 140px;      
              width: 20%;}
            .icon {
              margin: 3px 10px;
              z-index: 9999;                          
              cursor: pointer; }
            .icon.fixed {
              position: fixed;                            
            }
            .icon.inline{
              position: fixed;                                          
            }
            .bottom {
              bottom: 20px;}
            .left {
              left: 0px;}
            .right {
              right: 0px;}
        `}</style>

        </div>
      )
    }),
  Divider: () => {
    return (
      <div>
        <hr />
        <style jsx>{`
        `}</style>
      </div>
    )
  },
  Item: ({ children }) => (
    <a>{children}
      <style jsx>{`
          padding: 8px 8px 8px 30px;
          text-decoration: none;
          color: #818181;
          display: block;
          transition: 0.3s;
          cursor: pointer;              
          :hover, :focus {
              color: #f1f1f1;            
          }
        `}</style>
    </a >
  ),
  Title: ({ children }) => (
    <p>
      {children}
      <style jsx>{`
          cursor: default;
          margin-top: 60px;
          margin-left: 10px;
          font-size: 1.6em;        
          font-weight: bold;
          text-transform: uppercase;
        `}
      </style>
    </p>
  )
}

export default Sidenav